Class: Google::Apis::ServiceconsumermanagementV1beta1::Aspect

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Aspect represents Generic aspect. It is used to configure an aspect without making direct changes to service.proto

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Aspect

Returns a new instance of Aspect.



131
132
133
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 131

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

The type of this aspect configuration. Corresponds to the JSON property kind

Returns:

  • (String)


118
119
120
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 118

def kind
  @kind
end

#rulesArray<Google::Apis::ServiceconsumermanagementV1beta1::AspectRule>

Optional. Rules of the Configuration. Corresponds to the JSON property rules



123
124
125
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 123

def rules
  @rules
end

#specHash<String,Object>

Content of the configuration. The underlying schema should be defined by Aspect owners as protobuf message under google/api/configaspects/proto. Corresponds to the JSON property spec

Returns:

  • (Hash<String,Object>)


129
130
131
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 129

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



136
137
138
139
140
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 136

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @rules = args[:rules] if args.key?(:rules)
  @spec = args[:spec] if args.key?(:spec)
end