Class: Google::Apis::ServiceconsumermanagementV1beta1::Enum

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Enum

Returns a new instance of Enum.



1339
1340
1341
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1339

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


1311
1312
1313
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1311

def edition
  @edition
end

#enumvalueArray<Google::Apis::ServiceconsumermanagementV1beta1::EnumValue>

Enum value definitions. Corresponds to the JSON property enumvalue



1316
1317
1318
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1316

def enumvalue
  @enumvalue
end

#nameString

Enum type name. Corresponds to the JSON property name

Returns:

  • (String)


1321
1322
1323
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1321

def name
  @name
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1beta1::Option>

Protocol buffer options. Corresponds to the JSON property options



1326
1327
1328
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1326

def options
  @options
end

#source_contextGoogle::Apis::ServiceconsumermanagementV1beta1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



1332
1333
1334
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1332

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


1337
1338
1339
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1337

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1344
1345
1346
1347
1348
1349
1350
1351
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1344

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @enumvalue = args[:enumvalue] if args.key?(:enumvalue)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end