Class: Google::Apis::ServiceconsumermanagementV1beta1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



1493
1494
1495
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1493

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


1443
1444
1445
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1443

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


1448
1449
1450
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1448

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


1453
1454
1455
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1453

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


1458
1459
1460
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1458

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


1463
1464
1465
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1463

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1468
1469
1470
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1468

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


1474
1475
1476
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1474

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1beta1::Option>

The protocol buffer options. Corresponds to the JSON property options



1479
1480
1481
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1479

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


1484
1485
1486
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1484

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


1491
1492
1493
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1491

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1498

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end