Class: Google::Apis::ServiceconsumermanagementV1beta1::JwtLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Specifies a location to extract JWT from an API request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JwtLocation

Returns a new instance of JwtLocation.



1896
1897
1898
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Specifies cookie name to extract JWT token. Corresponds to the JSON property cookie

Returns:

  • (String)


1874
1875
1876
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1874

def cookie
  @cookie
end

#headerString

Specifies HTTP header name to extract JWT token. Corresponds to the JSON property header

Returns:

  • (String)


1879
1880
1881
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1879

def header
  @header
end

#queryString

Specifies URL query parameter name to extract JWT token. Corresponds to the JSON property query

Returns:

  • (String)


1884
1885
1886
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1884

def query
  @query
end

#value_prefixString

The value prefix. The value format is "value_prefixtoken" Only applies to " in" header type. Must be empty for "in" query type. If not empty, the header value has to match (case sensitive) this prefix. If not matched, JWT will not be extracted. If matched, JWT will be extracted after the prefix is removed. For example, for "Authorization: Bearer JWT", value_prefix="Bearer " with a space at the end. Corresponds to the JSON property valuePrefix

Returns:

  • (String)


1894
1895
1896
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1894

def value_prefix
  @value_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1901
1902
1903
1904
1905
1906
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1901

def update!(**args)
  @cookie = args[:cookie] if args.key?(:cookie)
  @header = args[:header] if args.key?(:header)
  @query = args[:query] if args.key?(:query)
  @value_prefix = args[:value_prefix] if args.key?(:value_prefix)
end