Class: Google::Apis::ServiceconsumermanagementV1beta1::MethodProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodProp

Returns a new instance of MethodProp.



2150
2151
2152
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property edition

Returns:

  • (String)


2110
2111
2112
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2110

def edition
  @edition
end

#nameString

The simple name of this method. Corresponds to the JSON property name

Returns:

  • (String)


2115
2116
2117
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2115

def name
  @name
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1beta1::Option>

Any metadata attached to the method. Corresponds to the JSON property options



2120
2121
2122
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2120

def options
  @options
end

#request_streamingBoolean Also known as: request_streaming?

If true, the request is streamed. Corresponds to the JSON property requestStreaming

Returns:

  • (Boolean)


2125
2126
2127
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2125

def request_streaming
  @request_streaming
end

#request_type_urlString

A URL of the input message type. Corresponds to the JSON property requestTypeUrl

Returns:

  • (String)


2131
2132
2133
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2131

def request_type_url
  @request_type_url
end

#response_streamingBoolean Also known as: response_streaming?

If true, the response is streamed. Corresponds to the JSON property responseStreaming

Returns:

  • (Boolean)


2136
2137
2138
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2136

def response_streaming
  @response_streaming
end

#response_type_urlString

The URL of the output message type. Corresponds to the JSON property responseTypeUrl

Returns:

  • (String)


2142
2143
2144
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2142

def response_type_url
  @response_type_url
end

#syntaxString

The source syntax of this method. This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property syntax

Returns:

  • (String)


2148
2149
2150
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2148

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2155

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @request_streaming = args[:request_streaming] if args.key?(:request_streaming)
  @request_type_url = args[:request_type_url] if args.key?(:request_type_url)
  @response_streaming = args[:response_streaming] if args.key?(:response_streaming)
  @response_type_url = args[:response_type_url] if args.key?(:response_type_url)
  @syntax = args[:syntax] if args.key?(:syntax)
end