Class: Google::Apis::ServiceconsumermanagementV1beta1::MethodSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::MethodSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
Describes the generator configuration for a method.
Instance Attribute Summary collapse
-
#auto_populated_fields ⇒ Array<String>
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).
-
#batching ⇒ Google::Apis::ServiceconsumermanagementV1beta1::BatchingConfigProto
BatchingConfigProtodefines the batching configuration for an API method. -
#long_running ⇒ Google::Apis::ServiceconsumermanagementV1beta1::LongRunning
Describes settings to use when generating API methods that use the long- running operation pattern.
-
#selector ⇒ String
The fully qualified name of the method, for which the options below apply.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MethodSettings
constructor
A new instance of MethodSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MethodSettings
Returns a new instance of MethodSettings.
2227 2228 2229 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_populated_fields ⇒ Array<String>
List of top-level fields of the request message, that should be automatically
populated by the client libraries based on their (google.api.field_info).
format. Currently supported format: UUID4. Example of a YAML configuration:
publishing: method_settings: - selector: google.example.v1.ExampleService.
CreateExample auto_populated_fields: - request_id
Corresponds to the JSON property autoPopulatedFields
2203 2204 2205 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2203 def auto_populated_fields @auto_populated_fields end |
#batching ⇒ Google::Apis::ServiceconsumermanagementV1beta1::BatchingConfigProto
BatchingConfigProto defines the batching configuration for an API method.
Corresponds to the JSON property batching
2208 2209 2210 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2208 def batching @batching end |
#long_running ⇒ Google::Apis::ServiceconsumermanagementV1beta1::LongRunning
Describes settings to use when generating API methods that use the long-
running operation pattern. All default values below are from those used in the
client library generators (e.g. Java).
Corresponds to the JSON property longRunning
2217 2218 2219 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2217 def long_running @long_running end |
#selector ⇒ String
The fully qualified name of the method, for which the options below apply.
This is used to find the method to apply the options. Example: publishing:
method_settings: - selector: google.storage.control.v2.StorageControl.
CreateFolder # method settings for CreateFolder...
Corresponds to the JSON property selector
2225 2226 2227 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2225 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2232 2233 2234 2235 2236 2237 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2232 def update!(**args) @auto_populated_fields = args[:auto_populated_fields] if args.key?(:auto_populated_fields) @batching = args[:batching] if args.key?(:batching) @long_running = args[:long_running] if args.key?(:long_running) @selector = args[:selector] if args.key?(:selector) end |