Class: Google::Apis::ServiceconsumermanagementV1beta1::MetricRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Bind API methods to metrics. Binding a method to a metric causes that metric's configured quota behaviors to apply to the method call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricRule

Returns a new instance of MetricRule.



2465
2466
2467
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentic_metric_costsHash<String,Fixnum>

Optional. Metrics to update when the selected methods are called, and the associated cost applied to each metric, iff the source of the call is an agent. The key of the map is the metric name, and the values are the amount increased for the metric against which the quota limits are defined. The value must not be negative. Corresponds to the JSON property agenticMetricCosts

Returns:

  • (Hash<String,Fixnum>)


2440
2441
2442
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2440

def agentic_metric_costs
  @agentic_metric_costs
end

#metric_costsHash<String,Fixnum>

Metrics to update when the selected methods are called, and the associated cost applied to each metric. The key of the map is the metric name, and the values are the amount increased for the metric against which the quota limits are defined. The value must not be negative. Corresponds to the JSON property metricCosts

Returns:

  • (Hash<String,Fixnum>)


2448
2449
2450
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2448

def metric_costs
  @metric_costs
end

#nonagentic_metric_costsHash<String,Fixnum>

Optional. Metrics to update when the selected methods are called, and the associated cost applied to each metric, iff the source of the call is not an agent. The key of the map is the metric name, and the values are the amount increased for the metric against which the quota limits are defined. The value must not be negative. Corresponds to the JSON property nonagenticMetricCosts

Returns:

  • (Hash<String,Fixnum>)


2457
2458
2459
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2457

def nonagentic_metric_costs
  @nonagentic_metric_costs
end

#selectorString

Selects the methods to which this rule applies. Refer to selector for syntax details. Corresponds to the JSON property selector

Returns:

  • (String)


2463
2464
2465
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2463

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2470
2471
2472
2473
2474
2475
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2470

def update!(**args)
  @agentic_metric_costs = args[:agentic_metric_costs] if args.key?(:agentic_metric_costs)
  @metric_costs = args[:metric_costs] if args.key?(:metric_costs)
  @nonagentic_metric_costs = args[:nonagentic_metric_costs] if args.key?(:nonagentic_metric_costs)
  @selector = args[:selector] if args.key?(:selector)
end