Class: Google::Apis::ServiceconsumermanagementV1beta1::Type
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::Type
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#fields ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Field>
The list of fields.
-
#name ⇒ String
The fully qualified message name.
-
#oneofs ⇒ Array<String>
The list of types appearing in
oneofdefinitions in this type. -
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Option>
The protocol buffer options.
-
#source_context ⇒ Google::Apis::ServiceconsumermanagementV1beta1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Type
constructor
A new instance of Type.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Type
Returns a new instance of Type.
3794 3795 3796 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
3761 3762 3763 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3761 def edition @edition end |
#fields ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Field>
The list of fields.
Corresponds to the JSON property fields
3766 3767 3768 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3766 def fields @fields end |
#name ⇒ String
The fully qualified message name.
Corresponds to the JSON property name
3771 3772 3773 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3771 def name @name end |
#oneofs ⇒ Array<String>
The list of types appearing in oneof definitions in this type.
Corresponds to the JSON property oneofs
3776 3777 3778 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3776 def oneofs @oneofs end |
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Option>
The protocol buffer options.
Corresponds to the JSON property options
3781 3782 3783 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3781 def @options end |
#source_context ⇒ Google::Apis::ServiceconsumermanagementV1beta1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
3787 3788 3789 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3787 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
3792 3793 3794 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3792 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3799 3800 3801 3802 3803 3804 3805 3806 3807 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3799 def update!(**args) @edition = args[:edition] if args.key?(:edition) @fields = args[:fields] if args.key?(:fields) @name = args[:name] if args.key?(:name) @oneofs = args[:oneofs] if args.key?(:oneofs) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |