Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1DisableConsumerResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Response message for the DisableConsumer method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1Beta1DisableConsumerResponse

Returns a new instance of V1Beta1DisableConsumerResponse.



4008
4009
4010
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4008

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4013
4014
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4013

def update!(**args)
end