Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1EnableConsumerResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Response message for the EnableConsumer method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1Beta1EnableConsumerResponse

Returns a new instance of V1Beta1EnableConsumerResponse.



4051
4052
4053
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4051

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4056
4057
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4056

def update!(**args)
end