Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaBucket
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaBucket
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
A quota bucket is a quota provisioning unit for a specific set of dimensions.
Instance Attribute Summary collapse
-
#admin_override ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaOverride
A quota override Corresponds to the JSON property
adminOverride. -
#consumer_override ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaOverride
A quota override Corresponds to the JSON property
consumerOverride. -
#default_limit ⇒ Fixnum
The default limit of this quota bucket, as specified by the service configuration.
-
#dimensions ⇒ Hash<String,String>
The dimensions of this quota bucket.
-
#effective_limit ⇒ Fixnum
The effective limit of this quota bucket.
-
#producer_override ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaOverride
A quota override Corresponds to the JSON property
producerOverride. -
#producer_quota_policy ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ProducerQuotaPolicy
Quota policy created by service producer.
-
#rollout_info ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1RolloutInfo
[Output only] Rollout information of a quota.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1Beta1QuotaBucket
constructor
A new instance of V1Beta1QuotaBucket.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1Beta1QuotaBucket
Returns a new instance of V1Beta1QuotaBucket.
4455 4456 4457 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_override ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaOverride
A quota override
Corresponds to the JSON property adminOverride
4410 4411 4412 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4410 def admin_override @admin_override end |
#consumer_override ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaOverride
A quota override
Corresponds to the JSON property consumerOverride
4415 4416 4417 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4415 def consumer_override @consumer_override end |
#default_limit ⇒ Fixnum
The default limit of this quota bucket, as specified by the service
configuration.
Corresponds to the JSON property defaultLimit
4421 4422 4423 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4421 def default_limit @default_limit end |
#dimensions ⇒ Hash<String,String>
The dimensions of this quota bucket. If this map is empty, this is the global
bucket, which is the default quota value applied to all requests that do not
have a more specific override. If this map is nonempty, the default limit,
effective limit, and quota overrides apply only to requests that have the
dimensions given in the map. For example, if the map has key "region" and
value "us-east-1", then the specified effective limit is only effective in
that region, and the specified overrides apply only in that region.
Corresponds to the JSON property dimensions
4432 4433 4434 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4432 def dimensions @dimensions end |
#effective_limit ⇒ Fixnum
The effective limit of this quota bucket. Equal to default_limit if there are
no overrides.
Corresponds to the JSON property effectiveLimit
4438 4439 4440 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4438 def effective_limit @effective_limit end |
#producer_override ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaOverride
A quota override
Corresponds to the JSON property producerOverride
4443 4444 4445 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4443 def producer_override @producer_override end |
#producer_quota_policy ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ProducerQuotaPolicy
Quota policy created by service producer.
Corresponds to the JSON property producerQuotaPolicy
4448 4449 4450 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4448 def producer_quota_policy @producer_quota_policy end |
#rollout_info ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1RolloutInfo
[Output only] Rollout information of a quota.
Corresponds to the JSON property rolloutInfo
4453 4454 4455 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4453 def rollout_info @rollout_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4460 def update!(**args) @admin_override = args[:admin_override] if args.key?(:admin_override) @consumer_override = args[:consumer_override] if args.key?(:consumer_override) @default_limit = args[:default_limit] if args.key?(:default_limit) @dimensions = args[:dimensions] if args.key?(:dimensions) @effective_limit = args[:effective_limit] if args.key?(:effective_limit) @producer_override = args[:producer_override] if args.key?(:producer_override) @producer_quota_policy = args[:producer_quota_policy] if args.key?(:producer_quota_policy) @rollout_info = args[:rollout_info] if args.key?(:rollout_info) end |