Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ServiceIdentity
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ServiceIdentity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
A service identity in the Identity and Access Management API.
Instance Attribute Summary collapse
-
#email ⇒ String
The email address of the service identity.
-
#name ⇒ String
P4 service identity resource name.
-
#project_role ⇒ String
The project-level IAM role defined in the service agent's grant configuration.
-
#tag ⇒ String
The P4 service identity configuration tag.
-
#unique_id ⇒ String
The unique and stable id of the service identity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1Beta1ServiceIdentity
constructor
A new instance of V1Beta1ServiceIdentity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1Beta1ServiceIdentity
Returns a new instance of V1Beta1ServiceIdentity.
4586 4587 4588 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
The email address of the service identity.
Corresponds to the JSON property email
4556 4557 4558 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4556 def email @email end |
#name ⇒ String
P4 service identity resource name. An example name would be: services/
serviceconsumermanagement.googleapis.com/projects/123/serviceIdentities/
default
Corresponds to the JSON property name
4563 4564 4565 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4563 def name @name end |
#project_role ⇒ String
The project-level IAM role defined in the service agent's grant configuration.
This is the standard role intended for this service agent. This field is
populated regardless of the skip_role_attach option in the request. If
skip_role_attach is true, the caller can use this value to know which role
they are responsible for granting.
Corresponds to the JSON property projectRole
4572 4573 4574 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4572 def project_role @project_role end |
#tag ⇒ String
The P4 service identity configuration tag. This must be defined in
activation_grants. If not specified when creating the account, the tag is set
to "default".
Corresponds to the JSON property tag
4579 4580 4581 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4579 def tag @tag end |
#unique_id ⇒ String
The unique and stable id of the service identity.
Corresponds to the JSON property uniqueId
4584 4585 4586 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4584 def unique_id @unique_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4591 4592 4593 4594 4595 4596 4597 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4591 def update!(**args) @email = args[:email] if args.key?(:email) @name = args[:name] if args.key?(:name) @project_role = args[:project_role] if args.key?(:project_role) @tag = args[:tag] if args.key?(:tag) @unique_id = args[:unique_id] if args.key?(:unique_id) end |