Class: Google::Apis::ServiceconsumermanagementV1beta1::V1beta1DefaultIdentity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

A default identity in the Identity and Access Management API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1beta1DefaultIdentity

Returns a new instance of V1beta1DefaultIdentity.



4652
4653
4654
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emailString

The email address of the default identity. Calling GenerateDefaultIdentity with a deleted or purged default identity should expect does_not_exist@invalid- project.iam.gserviceaccount.com placeholder email. Corresponds to the JSON property email

Returns:

  • (String)


4632
4633
4634
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4632

def email
  @email
end

#nameString

Default identity resource name. An example name would be: services/ serviceconsumermanagement.googleapis.com/projects/123/defaultIdentity Corresponds to the JSON property name

Returns:

  • (String)


4638
4639
4640
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4638

def name
  @name
end

#tagString

The Default Identity tag. If specified when creating the account, the tag must be present in activation_grants. If not specified when creating the account, the tag is set to the tag specified in activation_grants. Corresponds to the JSON property tag

Returns:

  • (String)


4645
4646
4647
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4645

def tag
  @tag
end

#unique_idString

The unique and stable id of the default identity. Corresponds to the JSON property uniqueId

Returns:

  • (String)


4650
4651
4652
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4650

def unique_id
  @unique_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4657
4658
4659
4660
4661
4662
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4657

def update!(**args)
  @email = args[:email] if args.key?(:email)
  @name = args[:name] if args.key?(:name)
  @tag = args[:tag] if args.key?(:tag)
  @unique_id = args[:unique_id] if args.key?(:unique_id)
end