Class: Google::Apis::ServiceconsumermanagementV1beta1::V1beta1DisableConsumerResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Response message for the DisableConsumer method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1beta1DisableConsumerResponse

Returns a new instance of V1beta1DisableConsumerResponse.



4669
4670
4671
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4669

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4674
4675
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4674

def update!(**args)
end