Class: Google::Apis::ServiceconsumermanagementV1beta1::V1beta1GenerateDefaultIdentityResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Response message for the GenerateDefaultIdentity method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1beta1GenerateDefaultIdentityResponse

Returns a new instance of V1beta1GenerateDefaultIdentityResponse.



4744
4745
4746
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attach_statusString

Status of the role attachment. Under development (go/si-attach-role), currently always return ATTACH_STATUS_UNSPECIFIED) Corresponds to the JSON property attachStatus

Returns:

  • (String)


4731
4732
4733
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4731

def attach_status
  @attach_status
end

#identityGoogle::Apis::ServiceconsumermanagementV1beta1::V1beta1DefaultIdentity

A default identity in the Identity and Access Management API. Corresponds to the JSON property identity



4736
4737
4738
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4736

def identity
  @identity
end

#roleString

Role attached to consumer project. Empty if not attached in this request. ( Under development, currently always return empty.) Corresponds to the JSON property role

Returns:

  • (String)


4742
4743
4744
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4742

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4749
4750
4751
4752
4753
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4749

def update!(**args)
  @attach_status = args[:attach_status] if args.key?(:attach_status)
  @identity = args[:identity] if args.key?(:identity)
  @role = args[:role] if args.key?(:role)
end