Class: Google::Apis::ServiceconsumermanagementV1beta1::V1beta1GenerateServiceAccountResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Response message for the GenerateServiceAccount method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1beta1GenerateServiceAccountResponse

Returns a new instance of V1beta1GenerateServiceAccountResponse.



4767
4768
4769
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountGoogle::Apis::ServiceconsumermanagementV1beta1::V1beta1ServiceAccount

A service account in the Identity and Access Management API. Corresponds to the JSON property account



4765
4766
4767
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4765

def 
  @account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4772
4773
4774
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4772

def update!(**args)
  @account = args[:account] if args.key?(:account)
end