Class: Google::Apis::ServiceconsumermanagementV1beta1::BatchingConfigProto
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::BatchingConfigProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
BatchingConfigProto defines the batching configuration for an API method.
Instance Attribute Summary collapse
-
#batch_descriptor ⇒ Google::Apis::ServiceconsumermanagementV1beta1::BatchingDescriptorProto
BatchingDescriptorProtospecifies the fields of the request message to be used for batching, and, optionally, the fields of the response message to be used for demultiplexing. -
#thresholds ⇒ Google::Apis::ServiceconsumermanagementV1beta1::BatchingSettingsProto
BatchingSettingsProtospecifies a set of batching thresholds, each of which acts as a trigger to send a batch of messages as a request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchingConfigProto
constructor
A new instance of BatchingConfigProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchingConfigProto
Returns a new instance of BatchingConfigProto.
513 514 515 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 513 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_descriptor ⇒ Google::Apis::ServiceconsumermanagementV1beta1::BatchingDescriptorProto
BatchingDescriptorProto specifies the fields of the request message to be
used for batching, and, optionally, the fields of the response message to be
used for demultiplexing.
Corresponds to the JSON property batchDescriptor
504 505 506 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 504 def batch_descriptor @batch_descriptor end |
#thresholds ⇒ Google::Apis::ServiceconsumermanagementV1beta1::BatchingSettingsProto
BatchingSettingsProto specifies a set of batching thresholds, each of which
acts as a trigger to send a batch of messages as a request. At least one
threshold must be positive nonzero.
Corresponds to the JSON property thresholds
511 512 513 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 511 def thresholds @thresholds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
518 519 520 521 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 518 def update!(**args) @batch_descriptor = args[:batch_descriptor] if args.key?(:batch_descriptor) @thresholds = args[:thresholds] if args.key?(:thresholds) end |