Class: Google::Apis::ServiceconsumermanagementV1beta1::EnumValue
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::EnumValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#name ⇒ String
Enum value name.
-
#number ⇒ Fixnum
Enum value number.
-
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Option>
Protocol buffer options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnumValue
constructor
A new instance of EnumValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnumValue
Returns a new instance of EnumValue.
1377 1378 1379 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Enum value name.
Corresponds to the JSON property name
1365 1366 1367 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1365 def name @name end |
#number ⇒ Fixnum
Enum value number.
Corresponds to the JSON property number
1370 1371 1372 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1370 def number @number end |
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Option>
Protocol buffer options.
Corresponds to the JSON property options
1375 1376 1377 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1375 def @options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1382 1383 1384 1385 1386 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1382 def update!(**args) @name = args[:name] if args.key?(:name) @number = args[:number] if args.key?(:number) @options = args[:options] if args.key?(:options) end |