Class: Google::Apis::ServiceconsumermanagementV1beta1::EnumValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnumValue

Returns a new instance of EnumValue.



1374
1375
1376
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Enum value name. Corresponds to the JSON property name

Returns:

  • (String)


1362
1363
1364
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1362

def name
  @name
end

#numberFixnum

Enum value number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1367
1368
1369
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1367

def number
  @number
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1beta1::Option>

Protocol buffer options. Corresponds to the JSON property options



1372
1373
1374
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1372

def options
  @options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1379
1380
1381
1382
1383
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1379

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @options = args[:options] if args.key?(:options)
end