Class: Google::Apis::ServiceconsumermanagementV1beta1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



1490
1491
1492
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


1440
1441
1442
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1440

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


1445
1446
1447
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1445

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


1450
1451
1452
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1450

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


1455
1456
1457
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1455

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


1460
1461
1462
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1460

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1465
1466
1467
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1465

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


1471
1472
1473
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1471

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1beta1::Option>

The protocol buffer options. Corresponds to the JSON property options



1476
1477
1478
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1476

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


1481
1482
1483
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1481

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


1488
1489
1490
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1488

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1495

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end