Class: Google::Apis::ServiceconsumermanagementV1beta1::Field
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::Field
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#cardinality ⇒ String
The field cardinality.
-
#default_value ⇒ String
The string value of the default value of this field.
-
#json_name ⇒ String
The field JSON name.
-
#kind ⇒ String
The field type.
-
#name ⇒ String
The field name.
-
#number ⇒ Fixnum
The field number.
-
#oneof_index ⇒ Fixnum
The index of the field type in
Type.oneofs, for message or enumeration types. -
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Option>
The protocol buffer options.
-
#packed ⇒ Boolean
(also: #packed?)
Whether to use alternative packed wire representation.
-
#type_url ⇒ String
The field type URL, without the scheme, for message or enumeration types.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Field
constructor
A new instance of Field.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Field
Returns a new instance of Field.
1490 1491 1492 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cardinality ⇒ String
The field cardinality.
Corresponds to the JSON property cardinality
1440 1441 1442 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1440 def cardinality @cardinality end |
#default_value ⇒ String
The string value of the default value of this field. Proto2 syntax only.
Corresponds to the JSON property defaultValue
1445 1446 1447 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1445 def default_value @default_value end |
#json_name ⇒ String
The field JSON name.
Corresponds to the JSON property jsonName
1450 1451 1452 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1450 def json_name @json_name end |
#kind ⇒ String
The field type.
Corresponds to the JSON property kind
1455 1456 1457 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1455 def kind @kind end |
#name ⇒ String
The field name.
Corresponds to the JSON property name
1460 1461 1462 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1460 def name @name end |
#number ⇒ Fixnum
The field number.
Corresponds to the JSON property number
1465 1466 1467 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1465 def number @number end |
#oneof_index ⇒ Fixnum
The index of the field type in Type.oneofs, for message or enumeration types.
The first type has index 1; zero means the type is not in the list.
Corresponds to the JSON property oneofIndex
1471 1472 1473 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1471 def oneof_index @oneof_index end |
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Option>
The protocol buffer options.
Corresponds to the JSON property options
1476 1477 1478 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1476 def @options end |
#packed ⇒ Boolean Also known as: packed?
Whether to use alternative packed wire representation.
Corresponds to the JSON property packed
1481 1482 1483 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1481 def packed @packed end |
#type_url ⇒ String
The field type URL, without the scheme, for message or enumeration types.
Example: "type.googleapis.com/google.protobuf.Timestamp".
Corresponds to the JSON property typeUrl
1488 1489 1490 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1488 def type_url @type_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 1495 def update!(**args) @cardinality = args[:cardinality] if args.key?(:cardinality) @default_value = args[:default_value] if args.key?(:default_value) @json_name = args[:json_name] if args.key?(:json_name) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @number = args[:number] if args.key?(:number) @oneof_index = args[:oneof_index] if args.key?(:oneof_index) @options = args[:options] if args.key?(:options) @packed = args[:packed] if args.key?(:packed) @type_url = args[:type_url] if args.key?(:type_url) end |