Class: Google::Apis::ServiceconsumermanagementV1beta1::MethodProp
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::MethodProp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#name ⇒ String
The simple name of this method.
-
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Option>
Any metadata attached to the method.
-
#request_streaming ⇒ Boolean
(also: #request_streaming?)
If true, the request is streamed.
-
#request_type_url ⇒ String
A URL of the input message type.
-
#response_streaming ⇒ Boolean
(also: #response_streaming?)
If true, the response is streamed.
-
#response_type_url ⇒ String
The URL of the output message type.
-
#syntax ⇒ String
The source syntax of this method.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MethodProp
constructor
A new instance of MethodProp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MethodProp
Returns a new instance of MethodProp.
2147 2148 2149 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS. This
field should be ignored, instead the edition should be inherited from Api.
This is similar to Field and EnumValue.
Corresponds to the JSON property edition
2107 2108 2109 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2107 def edition @edition end |
#name ⇒ String
The simple name of this method.
Corresponds to the JSON property name
2112 2113 2114 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2112 def name @name end |
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Option>
Any metadata attached to the method.
Corresponds to the JSON property options
2117 2118 2119 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2117 def @options end |
#request_streaming ⇒ Boolean Also known as: request_streaming?
If true, the request is streamed.
Corresponds to the JSON property requestStreaming
2122 2123 2124 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2122 def request_streaming @request_streaming end |
#request_type_url ⇒ String
A URL of the input message type.
Corresponds to the JSON property requestTypeUrl
2128 2129 2130 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2128 def request_type_url @request_type_url end |
#response_streaming ⇒ Boolean Also known as: response_streaming?
If true, the response is streamed.
Corresponds to the JSON property responseStreaming
2133 2134 2135 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2133 def response_streaming @response_streaming end |
#response_type_url ⇒ String
The URL of the output message type.
Corresponds to the JSON property responseTypeUrl
2139 2140 2141 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2139 def response_type_url @response_type_url end |
#syntax ⇒ String
The source syntax of this method. This field should be ignored, instead the
syntax should be inherited from Api. This is similar to Field and EnumValue.
Corresponds to the JSON property syntax
2145 2146 2147 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2145 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2152 def update!(**args) @edition = args[:edition] if args.key?(:edition) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @request_streaming = args[:request_streaming] if args.key?(:request_streaming) @request_type_url = args[:request_type_url] if args.key?(:request_type_url) @response_streaming = args[:response_streaming] if args.key?(:response_streaming) @response_type_url = args[:response_type_url] if args.key?(:response_type_url) @syntax = args[:syntax] if args.key?(:syntax) end |