Class: Google::Apis::ServiceconsumermanagementV1beta1::MetricRule
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::MetricRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
Bind API methods to metrics. Binding a method to a metric causes that metric's configured quota behaviors to apply to the method call.
Instance Attribute Summary collapse
-
#metric_costs ⇒ Hash<String,Fixnum>
Metrics to update when the selected methods are called, and the associated cost applied to each metric.
-
#selector ⇒ String
Selects the methods to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricRule
constructor
A new instance of MetricRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricRule
Returns a new instance of MetricRule.
2444 2445 2446 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metric_costs ⇒ Hash<String,Fixnum>
Metrics to update when the selected methods are called, and the associated
cost applied to each metric. The key of the map is the metric name, and the
values are the amount increased for the metric against which the quota limits
are defined. The value must not be negative.
Corresponds to the JSON property metricCosts
2436 2437 2438 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2436 def metric_costs @metric_costs end |
#selector ⇒ String
Selects the methods to which this rule applies. Refer to selector for syntax
details.
Corresponds to the JSON property selector
2442 2443 2444 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2442 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2449 2450 2451 2452 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2449 def update!(**args) @metric_costs = args[:metric_costs] if args.key?(:metric_costs) @selector = args[:selector] if args.key?(:selector) end |