Class: Google::Apis::ServiceconsumermanagementV1beta1::Publishing
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::Publishing
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
This message configures the settings for publishing Google Cloud Client libraries generated from the service config.
Instance Attribute Summary collapse
-
#api_short_name ⇒ String
Used as a tracking tag when collecting data about the APIs developer relations artifacts like docs, packages delivered to package managers, etc.
-
#codeowner_github_teams ⇒ Array<String>
GitHub teams to be added to CODEOWNERS in the directory in GitHub containing source code for the client libraries for this API.
-
#doc_tag_prefix ⇒ String
A prefix used in sample code when demarking regions to be included in documentation.
-
#documentation_uri ⇒ String
Link to product home page.
-
#github_label ⇒ String
GitHub label to apply to issues and pull requests opened for this API.
-
#library_settings ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::ClientLibrarySettings>
Client library settings.
-
#method_settings ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::MethodSettings>
A list of API method settings, e.g.
-
#new_issue_uri ⇒ String
Link to a public URI where users can report issues.
-
#organization ⇒ String
For whom the client library is being published.
-
#proto_reference_documentation_uri ⇒ String
Optional link to proto reference documentation.
-
#rest_reference_documentation_uri ⇒ String
Optional link to REST reference documentation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Publishing
constructor
A new instance of Publishing.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Publishing
Returns a new instance of Publishing.
2976 2977 2978 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2976 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_short_name ⇒ String
Used as a tracking tag when collecting data about the APIs developer relations
artifacts like docs, packages delivered to package managers, etc. Example: "
speech".
Corresponds to the JSON property apiShortName
2915 2916 2917 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2915 def api_short_name @api_short_name end |
#codeowner_github_teams ⇒ Array<String>
GitHub teams to be added to CODEOWNERS in the directory in GitHub containing
source code for the client libraries for this API.
Corresponds to the JSON property codeownerGithubTeams
2921 2922 2923 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2921 def codeowner_github_teams @codeowner_github_teams end |
#doc_tag_prefix ⇒ String
A prefix used in sample code when demarking regions to be included in
documentation.
Corresponds to the JSON property docTagPrefix
2927 2928 2929 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2927 def doc_tag_prefix @doc_tag_prefix end |
#documentation_uri ⇒ String
Link to product home page. Example: https://cloud.google.com/asset-inventory/
docs/overview
Corresponds to the JSON property documentationUri
2933 2934 2935 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2933 def documentation_uri @documentation_uri end |
#github_label ⇒ String
GitHub label to apply to issues and pull requests opened for this API.
Corresponds to the JSON property githubLabel
2938 2939 2940 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2938 def github_label @github_label end |
#library_settings ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::ClientLibrarySettings>
Client library settings. If the same version string appears multiple times in
this list, then the last one wins. Settings from earlier settings with the
same version string are discarded.
Corresponds to the JSON property librarySettings
2945 2946 2947 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2945 def library_settings @library_settings end |
#method_settings ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::MethodSettings>
A list of API method settings, e.g. the behavior for methods that use the long-
running operation pattern.
Corresponds to the JSON property methodSettings
2951 2952 2953 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2951 def method_settings @method_settings end |
#new_issue_uri ⇒ String
Link to a public URI where users can report issues. Example: https://
issuetracker.google.com/issues/new?component=190865&template=1161103
Corresponds to the JSON property newIssueUri
2957 2958 2959 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2957 def new_issue_uri @new_issue_uri end |
#organization ⇒ String
For whom the client library is being published.
Corresponds to the JSON property organization
2962 2963 2964 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2962 def organization @organization end |
#proto_reference_documentation_uri ⇒ String
Optional link to proto reference documentation. Example: https://cloud.google.
com/pubsub/lite/docs/reference/rpc
Corresponds to the JSON property protoReferenceDocumentationUri
2968 2969 2970 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2968 def proto_reference_documentation_uri @proto_reference_documentation_uri end |
#rest_reference_documentation_uri ⇒ String
Optional link to REST reference documentation. Example: https://cloud.google.
com/pubsub/lite/docs/reference/rest
Corresponds to the JSON property restReferenceDocumentationUri
2974 2975 2976 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2974 def rest_reference_documentation_uri @rest_reference_documentation_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2981 2982 2983 2984 2985 2986 2987 2988 2989 2990 2991 2992 2993 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2981 def update!(**args) @api_short_name = args[:api_short_name] if args.key?(:api_short_name) @codeowner_github_teams = args[:codeowner_github_teams] if args.key?(:codeowner_github_teams) @doc_tag_prefix = args[:doc_tag_prefix] if args.key?(:doc_tag_prefix) @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri) @github_label = args[:github_label] if args.key?(:github_label) @library_settings = args[:library_settings] if args.key?(:library_settings) @method_settings = args[:method_settings] if args.key?(:method_settings) @new_issue_uri = args[:new_issue_uri] if args.key?(:new_issue_uri) @organization = args[:organization] if args.key?(:organization) @proto_reference_documentation_uri = args[:proto_reference_documentation_uri] if args.key?(:proto_reference_documentation_uri) @rest_reference_documentation_uri = args[:rest_reference_documentation_uri] if args.key?(:rest_reference_documentation_uri) end |