Class: Google::Apis::ServiceconsumermanagementV1beta1::PythonSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::PythonSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
Settings for Python client libraries.
Instance Attribute Summary collapse
-
#common ⇒ Google::Apis::ServiceconsumermanagementV1beta1::CommonLanguageSettings
Required information for every language.
-
#experimental_features ⇒ Google::Apis::ServiceconsumermanagementV1beta1::ExperimentalFeatures
Experimental features to be included during client library generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PythonSettings
constructor
A new instance of PythonSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PythonSettings
Returns a new instance of PythonSettings.
3011 3012 3013 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common ⇒ Google::Apis::ServiceconsumermanagementV1beta1::CommonLanguageSettings
Required information for every language.
Corresponds to the JSON property common
3003 3004 3005 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3003 def common @common end |
#experimental_features ⇒ Google::Apis::ServiceconsumermanagementV1beta1::ExperimentalFeatures
Experimental features to be included during client library generation. These
fields will be deprecated once the feature graduates and is enabled by default.
Corresponds to the JSON property experimentalFeatures
3009 3010 3011 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3009 def experimental_features @experimental_features end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3016 3017 3018 3019 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3016 def update!(**args) @common = args[:common] if args.key?(:common) @experimental_features = args[:experimental_features] if args.key?(:experimental_features) end |