Class: Google::Apis::ServiceconsumermanagementV1beta1::PythonSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Settings for Python client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PythonSettings

Returns a new instance of PythonSettings.



2988
2989
2990
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commonGoogle::Apis::ServiceconsumermanagementV1beta1::CommonLanguageSettings

Required information for every language. Corresponds to the JSON property common



2980
2981
2982
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2980

def common
  @common
end

#experimental_featuresGoogle::Apis::ServiceconsumermanagementV1beta1::ExperimentalFeatures

Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default. Corresponds to the JSON property experimentalFeatures



2986
2987
2988
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2986

def experimental_features
  @experimental_features
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2993
2994
2995
2996
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 2993

def update!(**args)
  @common = args[:common] if args.key?(:common)
  @experimental_features = args[:experimental_features] if args.key?(:experimental_features)
end