Class: Google::Apis::ServiceconsumermanagementV1beta1::Type
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::Type
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#fields ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Field>
The list of fields.
-
#name ⇒ String
The fully qualified message name.
-
#oneofs ⇒ Array<String>
The list of types appearing in
oneofdefinitions in this type. -
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Option>
The protocol buffer options.
-
#source_context ⇒ Google::Apis::ServiceconsumermanagementV1beta1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Type
constructor
A new instance of Type.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Type
Returns a new instance of Type.
3766 3767 3768 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3766 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
3733 3734 3735 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3733 def edition @edition end |
#fields ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Field>
The list of fields.
Corresponds to the JSON property fields
3738 3739 3740 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3738 def fields @fields end |
#name ⇒ String
The fully qualified message name.
Corresponds to the JSON property name
3743 3744 3745 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3743 def name @name end |
#oneofs ⇒ Array<String>
The list of types appearing in oneof definitions in this type.
Corresponds to the JSON property oneofs
3748 3749 3750 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3748 def oneofs @oneofs end |
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::Option>
The protocol buffer options.
Corresponds to the JSON property options
3753 3754 3755 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3753 def @options end |
#source_context ⇒ Google::Apis::ServiceconsumermanagementV1beta1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
3759 3760 3761 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3759 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
3764 3765 3766 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3764 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3771 3772 3773 3774 3775 3776 3777 3778 3779 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3771 def update!(**args) @edition = args[:edition] if args.key?(:edition) @fields = args[:fields] if args.key?(:fields) @name = args[:name] if args.key?(:name) @oneofs = args[:oneofs] if args.key?(:oneofs) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |