Class: Google::Apis::ServiceconsumermanagementV1beta1::Type

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Type

Returns a new instance of Type.



3768
3769
3770
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


3735
3736
3737
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3735

def edition
  @edition
end

#fieldsArray<Google::Apis::ServiceconsumermanagementV1beta1::Field>

The list of fields. Corresponds to the JSON property fields



3740
3741
3742
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3740

def fields
  @fields
end

#nameString

The fully qualified message name. Corresponds to the JSON property name

Returns:

  • (String)


3745
3746
3747
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3745

def name
  @name
end

#oneofsArray<String>

The list of types appearing in oneof definitions in this type. Corresponds to the JSON property oneofs

Returns:

  • (Array<String>)


3750
3751
3752
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3750

def oneofs
  @oneofs
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1beta1::Option>

The protocol buffer options. Corresponds to the JSON property options



3755
3756
3757
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3755

def options
  @options
end

#source_contextGoogle::Apis::ServiceconsumermanagementV1beta1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



3761
3762
3763
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3761

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


3766
3767
3768
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3766

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3773
3774
3775
3776
3777
3778
3779
3780
3781
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3773

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @fields = args[:fields] if args.key?(:fields)
  @name = args[:name] if args.key?(:name)
  @oneofs = args[:oneofs] if args.key?(:oneofs)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end