Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaLimit
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaLimit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
Consumer quota settings for a quota limit.
Instance Attribute Summary collapse
-
#is_precise ⇒ Boolean
(also: #is_precise?)
Whether this limit is precise or imprecise.
-
#metric ⇒ String
The name of the parent metric of this limit.
-
#name ⇒ String
The resource name of the quota limit.
-
#quota_buckets ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaBucket>
Summary of the enforced quota buckets, organized by quota dimension, ordered from least specific to most specific (for example, the global default bucket, with no quota dimensions, will always appear first).
-
#supported_locations ⇒ Array<String>
List of all supported locations.
-
#unit ⇒ String
The limit unit.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1Beta1ConsumerQuotaLimit
constructor
A new instance of V1Beta1ConsumerQuotaLimit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1Beta1ConsumerQuotaLimit
Returns a new instance of V1Beta1ConsumerQuotaLimit.
3958 3959 3960 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_precise ⇒ Boolean Also known as: is_precise?
Whether this limit is precise or imprecise.
Corresponds to the JSON property isPrecise
3920 3921 3922 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3920 def is_precise @is_precise end |
#metric ⇒ String
The name of the parent metric of this limit. An example name would be:
compute.googleapis.com/cpus
Corresponds to the JSON property metric
3927 3928 3929 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3927 def metric @metric end |
#name ⇒ String
The resource name of the quota limit. An example name would be: services/
compute.googleapis.com/projects/123/consumerQuotaMetrics/compute.googleapis.
com%2Fcpus/limits/%2Fproject%2Fregion The resource name is intended to be
opaque and should not be parsed for its component strings, since its
representation could change in the future.
Corresponds to the JSON property name
3936 3937 3938 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3936 def name @name end |
#quota_buckets ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaBucket>
Summary of the enforced quota buckets, organized by quota dimension, ordered
from least specific to most specific (for example, the global default bucket,
with no quota dimensions, will always appear first).
Corresponds to the JSON property quotaBuckets
3943 3944 3945 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3943 def quota_buckets @quota_buckets end |
#supported_locations ⇒ Array<String>
List of all supported locations. This field is present only if the limit has a
region or zone dimension.
Corresponds to the JSON property supportedLocations
3949 3950 3951 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3949 def supported_locations @supported_locations end |
#unit ⇒ String
The limit unit. An example unit would be: 1/project/regionNote that
projectandregionare not placeholders in this example; the literal
charactersand`occur in the string.
Corresponds to the JSON propertyunit`
3956 3957 3958 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3956 def unit @unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3963 3964 3965 3966 3967 3968 3969 3970 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3963 def update!(**args) @is_precise = args[:is_precise] if args.key?(:is_precise) @metric = args[:metric] if args.key?(:metric) @name = args[:name] if args.key?(:name) @quota_buckets = args[:quota_buckets] if args.key?(:quota_buckets) @supported_locations = args[:supported_locations] if args.key?(:supported_locations) @unit = args[:unit] if args.key?(:unit) end |