Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaLimit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Consumer quota settings for a quota limit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1Beta1ConsumerQuotaLimit

Returns a new instance of V1Beta1ConsumerQuotaLimit.



3930
3931
3932
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3930

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_preciseBoolean Also known as: is_precise?

Whether this limit is precise or imprecise. Corresponds to the JSON property isPrecise

Returns:

  • (Boolean)


3892
3893
3894
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3892

def is_precise
  @is_precise
end

#metricString

The name of the parent metric of this limit. An example name would be: compute.googleapis.com/cpus Corresponds to the JSON property metric

Returns:

  • (String)


3899
3900
3901
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3899

def metric
  @metric
end

#nameString

The resource name of the quota limit. An example name would be: services/ compute.googleapis.com/projects/123/consumerQuotaMetrics/compute.googleapis. com%2Fcpus/limits/%2Fproject%2Fregion The resource name is intended to be opaque and should not be parsed for its component strings, since its representation could change in the future. Corresponds to the JSON property name

Returns:

  • (String)


3908
3909
3910
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3908

def name
  @name
end

#quota_bucketsArray<Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1QuotaBucket>

Summary of the enforced quota buckets, organized by quota dimension, ordered from least specific to most specific (for example, the global default bucket, with no quota dimensions, will always appear first). Corresponds to the JSON property quotaBuckets



3915
3916
3917
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3915

def quota_buckets
  @quota_buckets
end

#supported_locationsArray<String>

List of all supported locations. This field is present only if the limit has a region or zone dimension. Corresponds to the JSON property supportedLocations

Returns:

  • (Array<String>)


3921
3922
3923
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3921

def supported_locations
  @supported_locations
end

#unitString

The limit unit. An example unit would be: 1/project/regionNote that projectandregionare not placeholders in this example; the literal charactersand`occur in the string. Corresponds to the JSON propertyunit`

Returns:

  • (String)


3928
3929
3930
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3928

def unit
  @unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3935
3936
3937
3938
3939
3940
3941
3942
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3935

def update!(**args)
  @is_precise = args[:is_precise] if args.key?(:is_precise)
  @metric = args[:metric] if args.key?(:metric)
  @name = args[:name] if args.key?(:name)
  @quota_buckets = args[:quota_buckets] if args.key?(:quota_buckets)
  @supported_locations = args[:supported_locations] if args.key?(:supported_locations)
  @unit = args[:unit] if args.key?(:unit)
end