Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaMetric
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
Consumer quota settings for a quota metric.
Instance Attribute Summary collapse
-
#consumer_quota_limits ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaLimit>
The consumer quota for each quota limit defined on the metric.
-
#descendant_consumer_quota_limits ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaLimit>
The quota limits targeting the descendant containers of the consumer in request.
-
#display_name ⇒ String
The display name of the metric.
-
#metric ⇒ String
The name of the metric.
-
#name ⇒ String
The resource name of the quota settings on this metric for this consumer.
-
#unit ⇒ String
The units in which the metric value is reported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1Beta1ConsumerQuotaMetric
constructor
A new instance of V1Beta1ConsumerQuotaMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1Beta1ConsumerQuotaMetric
Returns a new instance of V1Beta1ConsumerQuotaMetric.
4015 4016 4017 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_quota_limits ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaLimit>
The consumer quota for each quota limit defined on the metric.
Corresponds to the JSON property consumerQuotaLimits
3980 3981 3982 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3980 def consumer_quota_limits @consumer_quota_limits end |
#descendant_consumer_quota_limits ⇒ Array<Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaLimit>
The quota limits targeting the descendant containers of the consumer in
request. If the consumer in request is of type organizations or folders,
the field will list per-project limits in the metric; if the consumer in
request is of type project, the field will be empty. The quota_buckets
field of each descendant consumer quota limit will not be populated.
Corresponds to the JSON property descendantConsumerQuotaLimits
3989 3990 3991 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3989 def descendant_consumer_quota_limits @descendant_consumer_quota_limits end |
#display_name ⇒ String
The display name of the metric. An example name would be: "CPUs"
Corresponds to the JSON property displayName
3994 3995 3996 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3994 def display_name @display_name end |
#metric ⇒ String
The name of the metric. An example name would be: compute.googleapis.com/cpus
Corresponds to the JSON property metric
3999 4000 4001 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3999 def metric @metric end |
#name ⇒ String
The resource name of the quota settings on this metric for this consumer. An
example name would be: services/serviceconsumermanagement.googleapis.com/
projects/123/consumerQuotaMetrics/compute.googleapis.com%2Fcpus The resource
name is intended to be opaque and should not be parsed for its component
strings, since its representation could change in the future.
Corresponds to the JSON property name
4008 4009 4010 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4008 def name @name end |
#unit ⇒ String
The units in which the metric value is reported.
Corresponds to the JSON property unit
4013 4014 4015 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4013 def unit @unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4020 4021 4022 4023 4024 4025 4026 4027 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4020 def update!(**args) @consumer_quota_limits = args[:consumer_quota_limits] if args.key?(:consumer_quota_limits) @descendant_consumer_quota_limits = args[:descendant_consumer_quota_limits] if args.key?(:descendant_consumer_quota_limits) @display_name = args[:display_name] if args.key?(:display_name) @metric = args[:metric] if args.key?(:metric) @name = args[:name] if args.key?(:name) @unit = args[:unit] if args.key?(:unit) end |