Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Consumer quota settings for a quota metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1Beta1ConsumerQuotaMetric

Returns a new instance of V1Beta1ConsumerQuotaMetric.



3987
3988
3989
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_quota_limitsArray<Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaLimit>

The consumer quota for each quota limit defined on the metric. Corresponds to the JSON property consumerQuotaLimits



3952
3953
3954
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3952

def consumer_quota_limits
  @consumer_quota_limits
end

#descendant_consumer_quota_limitsArray<Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ConsumerQuotaLimit>

The quota limits targeting the descendant containers of the consumer in request. If the consumer in request is of type organizations or folders, the field will list per-project limits in the metric; if the consumer in request is of type project, the field will be empty. The quota_buckets field of each descendant consumer quota limit will not be populated. Corresponds to the JSON property descendantConsumerQuotaLimits



3961
3962
3963
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3961

def descendant_consumer_quota_limits
  @descendant_consumer_quota_limits
end

#display_nameString

The display name of the metric. An example name would be: "CPUs" Corresponds to the JSON property displayName

Returns:

  • (String)


3966
3967
3968
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3966

def display_name
  @display_name
end

#metricString

The name of the metric. An example name would be: compute.googleapis.com/cpus Corresponds to the JSON property metric

Returns:

  • (String)


3971
3972
3973
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3971

def metric
  @metric
end

#nameString

The resource name of the quota settings on this metric for this consumer. An example name would be: services/serviceconsumermanagement.googleapis.com/ projects/123/consumerQuotaMetrics/compute.googleapis.com%2Fcpus The resource name is intended to be opaque and should not be parsed for its component strings, since its representation could change in the future. Corresponds to the JSON property name

Returns:

  • (String)


3980
3981
3982
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3980

def name
  @name
end

#unitString

The units in which the metric value is reported. Corresponds to the JSON property unit

Returns:

  • (String)


3985
3986
3987
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3985

def unit
  @unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3992
3993
3994
3995
3996
3997
3998
3999
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 3992

def update!(**args)
  @consumer_quota_limits = args[:consumer_quota_limits] if args.key?(:consumer_quota_limits)
  @descendant_consumer_quota_limits = args[:descendant_consumer_quota_limits] if args.key?(:descendant_consumer_quota_limits)
  @display_name = args[:display_name] if args.key?(:display_name)
  @metric = args[:metric] if args.key?(:metric)
  @name = args[:name] if args.key?(:name)
  @unit = args[:unit] if args.key?(:unit)
end