Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ImportProducerOverridesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ImportProducerOverridesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
Request message for ImportProducerOverrides
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Whether to force the creation of the quota overrides.
-
#force_justification ⇒ String
If force option is set to true, force_justification is suggested to be set to log the reason in audit logs.
-
#force_only ⇒ Array<String>
The list of quota safety checks to ignore before the override mutation.
-
#inline_source ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1OverrideInlineSource
Import data embedded in the request message Corresponds to the JSON property
inlineSource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1Beta1ImportProducerOverridesRequest
constructor
A new instance of V1Beta1ImportProducerOverridesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1Beta1ImportProducerOverridesRequest
Returns a new instance of V1Beta1ImportProducerOverridesRequest.
4084 4085 4086 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Whether to force the creation of the quota overrides. Setting the force
parameter to 'true' ignores all quota safety checks that would fail the
request. QuotaSafetyCheck lists all such validations.
Corresponds to the JSON property force
4062 4063 4064 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4062 def force @force end |
#force_justification ⇒ String
If force option is set to true, force_justification is suggested to be set to
log the reason in audit logs.
Corresponds to the JSON property forceJustification
4069 4070 4071 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4069 def force_justification @force_justification end |
#force_only ⇒ Array<String>
The list of quota safety checks to ignore before the override mutation. Unlike
'force' field that ignores all the quota safety checks, the 'force_only' field
ignores only the specified checks; other checks are still enforced. The 'force'
and 'force_only' fields cannot both be set.
Corresponds to the JSON property forceOnly
4077 4078 4079 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4077 def force_only @force_only end |
#inline_source ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1OverrideInlineSource
Import data embedded in the request message
Corresponds to the JSON property inlineSource
4082 4083 4084 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4082 def inline_source @inline_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4089 4090 4091 4092 4093 4094 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4089 def update!(**args) @force = args[:force] if args.key?(:force) @force_justification = args[:force_justification] if args.key?(:force_justification) @force_only = args[:force_only] if args.key?(:force_only) @inline_source = args[:inline_source] if args.key?(:inline_source) end |