Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ImportProducerQuotaPoliciesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ImportProducerQuotaPoliciesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb
Overview
Request message for ImportProducerQuotaPolicies
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Whether quota policy can result in a decrease of effective limit.
-
#force_justification ⇒ String
If force or force_skip_quota_usage_check option is set to true, force_justification is suggested to be set to log the reason in audit logs.
-
#force_skip_quota_usage_check ⇒ Boolean
(also: #force_skip_quota_usage_check?)
If set to true, skip the quota usage check.
-
#inline_source ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1PolicyInlineSource
Import data embedded in the request message Corresponds to the JSON property
inlineSource. -
#validate_only ⇒ Boolean
(also: #validate_only?)
If set to true, validate the request, but do not actually update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1Beta1ImportProducerQuotaPoliciesRequest
constructor
A new instance of V1Beta1ImportProducerQuotaPoliciesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1Beta1ImportProducerQuotaPoliciesRequest
Returns a new instance of V1Beta1ImportProducerQuotaPoliciesRequest.
4183 4184 4185 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Whether quota policy can result in a decrease of effective limit. Don't allow
any decreases if force is not specified. If force is specified, then don't
allow any decreases below 120% of the 7d quota usage, or for cases where usage
cannot be examined (custom dimensions/ per user/per resource), only allow a 10%
decrease.
Corresponds to the JSON property force
4155 4156 4157 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4155 def force @force end |
#force_justification ⇒ String
If force or force_skip_quota_usage_check option is set to true,
force_justification is suggested to be set to log the reason in audit logs.
Corresponds to the JSON property forceJustification
4162 4163 4164 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4162 def force_justification @force_justification end |
#force_skip_quota_usage_check ⇒ Boolean Also known as: force_skip_quota_usage_check?
If set to true, skip the quota usage check. This field is only used when the
effective limit can be decreased. If the force field is not set, this field
will be ignored.
Corresponds to the JSON property forceSkipQuotaUsageCheck
4169 4170 4171 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4169 def force_skip_quota_usage_check @force_skip_quota_usage_check end |
#inline_source ⇒ Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1PolicyInlineSource
Import data embedded in the request message
Corresponds to the JSON property inlineSource
4175 4176 4177 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4175 def inline_source @inline_source end |
#validate_only ⇒ Boolean Also known as: validate_only?
If set to true, validate the request, but do not actually update.
Corresponds to the JSON property validateOnly
4180 4181 4182 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4180 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4188 4189 4190 4191 4192 4193 4194 |
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4188 def update!(**args) @force = args[:force] if args.key?(:force) @force_justification = args[:force_justification] if args.key?(:force_justification) @force_skip_quota_usage_check = args[:force_skip_quota_usage_check] if args.key?(:force_skip_quota_usage_check) @inline_source = args[:inline_source] if args.key?(:inline_source) @validate_only = args[:validate_only] if args.key?(:validate_only) end |