Class: Google::Apis::ServiceconsumermanagementV1beta1::V1Beta1ImportProducerQuotaPoliciesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Request message for ImportProducerQuotaPolicies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1Beta1ImportProducerQuotaPoliciesRequest

Returns a new instance of V1Beta1ImportProducerQuotaPoliciesRequest.



4155
4156
4157
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

Whether quota policy can result in a decrease of effective limit. Don't allow any decreases if force is not specified. If force is specified, then don't allow any decreases below 120% of the 7d quota usage, or for cases where usage cannot be examined (custom dimensions/ per user/per resource), only allow a 10% decrease. Corresponds to the JSON property force

Returns:

  • (Boolean)


4127
4128
4129
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4127

def force
  @force
end

#force_justificationString

If force or force_skip_quota_usage_check option is set to true, force_justification is suggested to be set to log the reason in audit logs. Corresponds to the JSON property forceJustification

Returns:

  • (String)


4134
4135
4136
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4134

def force_justification
  @force_justification
end

#force_skip_quota_usage_checkBoolean Also known as: force_skip_quota_usage_check?

If set to true, skip the quota usage check. This field is only used when the effective limit can be decreased. If the force field is not set, this field will be ignored. Corresponds to the JSON property forceSkipQuotaUsageCheck

Returns:

  • (Boolean)


4141
4142
4143
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4141

def force_skip_quota_usage_check
  @force_skip_quota_usage_check
end

#inline_sourceGoogle::Apis::ServiceconsumermanagementV1beta1::V1Beta1PolicyInlineSource

Import data embedded in the request message Corresponds to the JSON property inlineSource



4147
4148
4149
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4147

def inline_source
  @inline_source
end

#validate_onlyBoolean Also known as: validate_only?

If set to true, validate the request, but do not actually update. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


4152
4153
4154
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4152

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4160
4161
4162
4163
4164
4165
4166
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4160

def update!(**args)
  @force = args[:force] if args.key?(:force)
  @force_justification = args[:force_justification] if args.key?(:force_justification)
  @force_skip_quota_usage_check = args[:force_skip_quota_usage_check] if args.key?(:force_skip_quota_usage_check)
  @inline_source = args[:inline_source] if args.key?(:inline_source)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end