Class: Google::Apis::ServiceconsumermanagementV1beta1::V1beta1AddVisibilityLabelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1beta1/representations.rb

Overview

Response message for the AddVisibilityLabels method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1beta1AddVisibilityLabelsResponse

Returns a new instance of V1beta1AddVisibilityLabelsResponse.



4613
4614
4615
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsArray<String>

The updated set of visibility labels for this consumer on this service. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


4611
4612
4613
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4611

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4618
4619
4620
# File 'lib/google/apis/serviceconsumermanagement_v1beta1/classes.rb', line 4618

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
end